@@ -1,5 +1,5 @@
 #' @export
-polyDlm.default = function(x , y , q , k , show.beta = TRUE){
+polyDlm.default <- function(x , y , q , k , show.beta = TRUE){
   
   options(warn=-1)
   
@@ -15,8 +15,8 @@ polyDlm.default = function(x , y , q , k , show.beta = TRUE){
     stop("The order of polynomial must be an integer greater than or equal to 1!")
   }
   
-  res = polyDlm.main(x = x , y = y , q = q , k = k , show.beta = show.beta)
-  res$call = match.call()
-  class(res) = c("polyDlm" , "dLagM")
+  res <- polyDlm.main(x = x , y = y , q = q , k = k , show.beta = show.beta)
+  res$call <- match.call()
+  class(res) <- c("polyDlm" , "dLagM")
   res
 }
\ No newline at end of file
